# Changelog for https://gitlab.com/mbarkhau/pycalver

## v201812.0008-beta

 - Add version tags using git/hg.
 - Use git/hg tags as SSOT for most recent version.
 - Start using https://gitlab.com/mbarkhau/bootstrapit
 - Move to https://gitlab.com/mbarkhau/pycalver

## v201809.0001-alpha

 - Initial release
